import { select, 
        arc,
        csv,
        scaleLinear,
        max,
        scaleBand,
        axisLeft,
        axisBottom,
        format} 
from 'd3';

const width = 1000
const height = 1000
 
const svg = d3.select('.barchart')
                 .attr('height',height)
                 .attr('width',width)

 
const render = (data) => {
  
      const margin = { left:135,right:200, top:150,bottom:90 };
      const innerWidth = width - margin.left - margin.right;
      const innerHeight = width - margin.top - margin.bottom;
  
      const xFormat = x => { return format(".3s")(x).replace('M','B');  } ;
  
      const xValue = d => { return d.population }
      const yValue = d => { return d.country }
      
      
      
      const xScale = scaleLinear()
                        .domain([0,max(data,xValue)])
                        .range([0,innerWidth]);
  
      const yScale = scaleBand().domain(data.map(yValue))
                                .range([0,innerHeight])
                                .padding(0.2);
  
      const yaxis = axisLeft(yScale); 
  
      const xaxis = axisBottom(xScale).tickFormat(xFormat).tickSize(-innerHeight); 
  
      console.log(yScale.domain());
  
      const g = svg.append('g')
                     .attr('transform',`translate(${margin.left},${margin.top})`);

  
      const y_view = g.append('g').call(yaxis)
                           .attr('class','y-label')
            
      y_view.selectAll('.domain, .tick line').remove();
 
      const x_view = g.append('g').call(xaxis)
                           .attr('transform',`translate(0,${innerHeight})`)
                           .attr('class','x-label')
                            
      x_view.selectAll('.domain').remove();
  
      x_view.append('text').text('Population')
                           .attr('fill','black')
                           .attr('x',`${innerHeight/2}`)
                           .attr('y',`55`)
                           .attr('class','axis-label');  
      
  
      console.log(g);
   
      g.selectAll('rect').data(data).enter().append('rect')
                                            .attr('width', d => { return xScale(d.population)  } )
                                            .attr('height',yScale.bandwidth())
                                            .attr('y', d => yScale(d.country) )
  
  
      g.append('text').text('Sample bar chart')
                      .attr('y',-10)
                      .attr('class','chart-title');   
                       
                                                  
   }
 
csv('population.csv').then( 
   (row) => {
     row.forEach( r => { r.population = +r.population  } );
     console.log(row)
     
     render(row);
   }
);
 
 
